=============
Release notes
=============

.. towncrier release notes start

v1.0.0
======

This is a the first stable release, as deployed in production in the Fedora infrastructure
on March 24th 2021.


Contributors
^^^^^^^^^^^^

Many thanks to the contributors of bug reports, pull requests, and pull request
reviews for this release:

* Alain Reguera Delgado
* Aurélien Bompard
* Jan Kuparinen
* james02135
* Jean-Baptiste Holcroft
* Neal Gompa
* Nils Philippsen
* Rafael Fontenelle
* Ricky Tigg
* Ryan Lerch
* simmon
* Stephen Coady
